@@ -66,12 +66,12 @@ sub build_dynamic_lib_dist {
     exit(255);
   }
   my $runtime = $compiler->get_runtime;
-  my $module_file = $runtime->get_module_file($basic_type_name);
+  my $class_file = $runtime->get_class_file($basic_type_name);
   my $method_names = $runtime->get_method_names($basic_type_name, $category);
   my $precompile_source = $runtime->build_precompile_module_source($basic_type_name);
   my $dl_func_list = SPVM::Builder::Util::create_dl_func_list($basic_type_name, $method_names, {category => $category});
   
-  $self->build_dist($basic_type_name, {category => $category, module_file => $module_file, dl_func_list => $dl_func_list, precompile_source => $precompile_source});
+  $self->build_dist($basic_type_name, {category => $category, class_file => $class_file, dl_func_list => $dl_func_list, precompile_source => $precompile_source});
 }
 
 sub build_dist {
@@ -82,7 +82,7 @@ sub build_dist {
   my $build_dir = $self->build_dir;
   
   my $dl_func_list = $options->{dl_func_list};
-  my $module_file = $options->{module_file};
+  my $class_file = $options->{class_file};
   my $precompile_source = $options->{precompile_source};
   
   my $category = $options->{category};
@@ -101,7 +101,7 @@ sub build_dist {
       {
         output_dir => $build_src_dir,
         precompile_source => $precompile_source,
-        module_file => $module_file,
+        class_file => $class_file,
       }
     );
   }
@@ -121,7 +121,7 @@ sub build_dist {
       compile_output_dir => $build_object_dir,
       link_output_dir => $build_lib_dir,
       category => $category,
-      module_file => $module_file,
+      class_file => $class_file,
       dl_func_list => $dl_func_list,
     }
   );
@@ -147,7 +147,7 @@ sub build_at_runtime {
   my $build_dir = $self->build_dir;
   
   my $dl_func_list = $options->{dl_func_list};
-  my $module_file = $options->{module_file};
+  my $class_file = $options->{class_file};
   my $precompile_source = $options->{precompile_source};
 
   my $category = $options->{category};
@@ -176,13 +176,13 @@ sub build_at_runtime {
       {
         output_dir => $build_src_dir,
         precompile_source => $precompile_source,
-        module_file => $module_file,
+        class_file => $class_file,
       }
     );
   }
   elsif ($category eq 'native') {
-    my $module_file = $options->{module_file};
-    $build_src_dir = SPVM::Builder::Util::remove_basic_type_name_part_from_file($module_file, $basic_type_name);
+    my $class_file = $options->{class_file};
+    $build_src_dir = SPVM::Builder::Util::remove_basic_type_name_part_from_file($class_file, $basic_type_name);
   }
   
   # Object directory
@@ -200,7 +200,7 @@ sub build_at_runtime {
       compile_output_dir => $build_object_dir,
       link_output_dir => $build_lib_dir,
       category => $category,
-      module_file => $module_file,
+      class_file => $class_file,
       dl_func_list => $dl_func_list,
       at_runtime => 1,
     }
@@ -227,27 +227,27 @@ sub build {
   my $category = $options->{category};
   
   # Class file
-  my $module_file = $options->{module_file};
-  unless (defined $module_file) {
+  my $class_file = $options->{class_file};
+  unless (defined $class_file) {
     my $config_file = SPVM::Builder::Util::get_config_file_from_basic_type_name($basic_type_name);
     if ($config_file) {
-      $module_file = $config_file;
-      $module_file =~ s/\.config$/\.spvm/;
+      $class_file = $config_file;
+      $class_file =~ s/\.config$/\.spvm/;
     }
     else {
-      confess "The module file \"$module_file\" is not found";
+      confess "The class file \"$class_file\" is not found";
     }
   }
   
   my $config;
   if ($category eq 'native') {
-    $config = $self->create_native_config_from_module_file($module_file);
+    $config = $self->create_native_config_from_class_file($class_file);
   }
   elsif ($category eq 'precompile') {
     $config = SPVM::Builder::Util::API::create_default_config();
   }
   
-  $config->module_name($basic_type_name);
+  $config->class_name($basic_type_name);
   
   # Compile source file and create object files
   my $compile_options = {
@@ -275,11 +275,11 @@ sub build {
   return $output_file;
 }
 
-sub create_native_config_from_module_file {
-  my ($self, $module_file) = @_;
+sub create_native_config_from_class_file {
+  my ($self, $class_file) = @_;
   
   my $config;
-  my $config_file = $module_file;
+  my $config_file = $class_file;
   $config_file =~ s/\.spvm$/.config/;
 
   # Config file
