@@ -496,7 +496,7 @@ enum {
   SPVM_OPCODE_C_ID_RETURN_MULNUM_LONG,
   SPVM_OPCODE_C_ID_RETURN_MULNUM_FLOAT,
   SPVM_OPCODE_C_ID_RETURN_MULNUM_DOUBLE,
-  SPVM_OPCODE_C_ID_ITEMS,
+  SPVM_OPCODE_C_ID_ARGS_WIDTH,
   SPVM_OPCODE_C_ID_CALL_CLASS_METHOD,
   SPVM_OPCODE_C_ID_CALL_INSTANCE_METHOD_STATIC,
   SPVM_OPCODE_C_ID_CALL_INSTANCE_METHOD,
