@@ -4,22 +4,11 @@
 #include "bar.h"
 #include "baz/baz.h"
 
-int32_t SPVM__TestCase__NativeAPI2__mul(SPVM_ENV* env, SPVM_VALUE* stack) {
-  (void)env;
-  (void)stack;
-
-  int32_t total = stack[0].ival * stack[1].ival;
-  
-  stack[0].ival = total;
-  
-  return 0;
-}
-
 int32_t SPVM__TestCase__NativeAPI2__src_foo(SPVM_ENV* env, SPVM_VALUE* stack) {
-  (void)env;
-  (void)stack;
   
-  if (foo() == 3) {
+  int32_t value = foo();
+  
+  if (value == 3) {
     stack[0].ival = 1;
   }
   else {
@@ -30,10 +19,10 @@ int32_t SPVM__TestCase__NativeAPI2__src_foo(SPVM_ENV* env, SPVM_VALUE* stack) {
 }
 
 int32_t SPVM__TestCase__NativeAPI2__src_bar(SPVM_ENV* env, SPVM_VALUE* stack) {
-  (void)env;
-  (void)stack;
-
-  if (bar() == 4) {
+  
+  int32_t value = bar();
+  
+  if (value == 4) {
     stack[0].ival = 1;
   }
   else {
@@ -44,10 +33,10 @@ int32_t SPVM__TestCase__NativeAPI2__src_bar(SPVM_ENV* env, SPVM_VALUE* stack) {
 }
 
 int32_t SPVM__TestCase__NativeAPI2__src_baz(SPVM_ENV* env, SPVM_VALUE* stack) {
-  (void)env;
-  (void)stack;
-
-  if (baz() == 5) {
+  
+  int32_t value = baz();
+  
+  if (value == 6) {
     stack[0].ival = 1;
   }
   else {
